backend_execute

Function backend_execute 

pub unsafe fn backend_execute(
    handle: cudnnHandle_t,
    plan: &BackendDescriptor,
    variant_pack: &BackendDescriptor,
) -> Result<(), GpuError>
Run a finalised execution plan against a finalised variant pack.

Safety

Both descriptors must be finalised. handle must be valid for the stream the plan was built against.